@@ -103,10 +103,34 @@ def filter() -> None:
 
 
 def stream() -> None:
+    import random
     import sys
+    import time
 
     from naveen.data.url_streamer import stream_url
 
+    parser = argparse.ArgumentParser()
+    parser.add_argument(
+        "-d",
+        "--d",
+        "-delay",
+        "--delay",
+        type=int,
+        dest="delay",
+        default=0,
+        required=False,
+    )
+
+    parser.add_argument(
+        "-v",
+        "--verbose",
+        dest="verbose",
+        default=False,
+        action=argparse.BooleanOptionalAction,
+    )  # type: ignore
+
+    args = parser.parse_args()
+
     if sys.stdin.isatty():  # no pipe
         print("- You must pipe input to stream")
         import os
@@ -115,6 +139,10 @@ def stream() -> None:
 
     for line in sys.stdin:  # for line in pipe
         line = line.replace("\n", "")
+        delay = random.uniform(0, args.delay)
+        if args.verbose:
+            print(f"[*] sleeping for {delay:.1f} seconds")
+        time.sleep(delay)
         stream_url(line)
 
 
@@ -379,4 +407,4 @@ def experiment() -> None:
 
 if __name__ == "__main__":
     a = 5
-    print(a)
+    stream()
